# Glossary

| item | definition|
|------|-----------|
| checker type | A type of the check to be executed. Like `lines_present` |
| checker object | The object being checked, like a file |
| checker | A concrete instance of a check to be executed, like an `lines_present` for the object `~/.bashrc` |
| check | A concrete execution of a checker |
